@@ -1,7 +1,7 @@
 package POE::Component::IKC::Channel;
 
 ############################################################
-# $Id: Channel.pm 168 2006-11-16 19:57:48Z fil $
+# $Id: Channel.pm 311 2007-11-29 21:15:53Z fil $
 # Based on tests/refserver.perl
 # Contributed by Artur Bergman <artur@vogon-solutions.com>
 # Revised for 0.06 by Rocco Caputo <troc@netrus.net>
@@ -27,7 +27,7 @@ use Data::Dumper;
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(create_ikc_channel);
-$VERSION = '0.1903';
+$VERSION = '0.2000';
 
 sub DEBUG { 0 }
 
@@ -281,8 +281,10 @@ sub server_000
     unless(defined $line) {
         # wait for client to send HELLO
     } 
-    elsif( $line eq 'HELLO' or 
-                $line =~ /^HELLO IKC\d+$/ ) {         # compatible with IKC1
+    elsif( $line =~ /^HELLO IKC\d$/ ) {         # compatible with IKC1
+        $heap->{'wheel_client'}->put( 'NOT' );
+    }
+    elsif( $line eq 'HELLO' ) {
         $heap->{'wheel_client'}->put('IAM '.$kernel->ID());
 
         # put other server aliases here
@@ -621,13 +623,16 @@ sub channel_send
 {
     my ($heap, $request)=@_[HEAP, ARG0];
 
-    DEBUG && warn "$$: Sending data...\n";
+    DEBUG && 
+        warn "$$: Sending data...\n";
         # add our name so the foreign channel can find us
         # TODO should we do this?  or should the other end do this?
     $request->{rsvp}->{kernel}||=$heap->{kernel_name}
             if ref($request) and $request->{rsvp};
 
     if($heap->{'wheel_client'}) {
+        # use Data::Dumper;
+        # warn "Sending ", Dumper $request;
         $heap->{'wheel_client'}->put($request);
     }
     else {
@@ -647,7 +652,8 @@ sub channel_send
 sub channel_flushed
 {
     my($heap, $wheel)=@_[HEAP, ARG0];
-    DEBUG && warn "$$: Flushed data...\n";
+    DEBUG && 
+        warn "$$: Flushed data...\n";
     if($heap->{go_away}) {
         _close_channel($heap);
     }
@@ -809,30 +815,3 @@ L<POE::Component::IKC::Responder>
 =cut
 
 
-$Log$
-Revision 1.20.2.3  2006/11/01 18:30:53  fil
-Moved to version 0.1902
-
-Revision 1.20.2.2  2006/10/04 18:55:19  fil
-Tweak POD
-Add IKC.pm to MANIFEST
-
-Revision 1.20.2.1  2006/10/03 22:52:31  fil
-Fixed memory leak
-Added IKC.pm
-
-Revision 1.20  2005/09/14 02:02:54  fil
-Version from IKC/Responder
-Now use Session->create, not ->new
-Improved formating
-DEBUG warnings, not print
-Proxy uses call() to work around the @$etc=() bug in POE
-
-Revision 1.19  2005/08/04 22:01:30  fil
-Fixed Channel shutdown code
-Documented how to shutdown a channel
-Freezer now checks for nfreeze first
-Moved to version 0.18
-Added USR1 (non-verbose kernel state dumping) to Server
-Improved Server kernel state dumping
-
