@@ -1,8 +1,8 @@
-# $Id: Proxy.pm 168 2006-11-16 19:57:48Z fil $
+# $Id: Proxy.pm 311 2007-11-29 21:15:53Z fil $
 package POE::Component::IKC::Proxy;
 
 ##############################################################################
-# $Id: Proxy.pm 168 2006-11-16 19:57:48Z fil $
+# $Id: Proxy.pm 311 2007-11-29 21:15:53Z fil $
 # Copyright 1999,2002,2004 Philip Gwyn.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
@@ -21,7 +21,7 @@ use POE::Component::IKC::Specifier;
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(create_ikc_proxy);
-$VERSION = '0.1903';
+$VERSION = '0.2000';
 
 sub DEBUG { 0 }
 
@@ -164,61 +164,3 @@ L<POE>, L<POE::Component::IKC>
 =cut
 
 
-$Log$
-Revision 1.13.2.1  2006/11/01 18:30:54  fil
-Moved to version 0.1902
-
-Revision 1.13  2005/09/14 02:02:54  fil
-Version from IKC/Responder
-Now use Session->create, not ->new
-Improved formating
-DEBUG warnings, not print
-Proxy uses call() to work around the @$etc=() bug in POE
-
-Revision 1.12  2005/08/04 22:01:30  fil
-Fixed Channel shutdown code
-Documented how to shutdown a channel
-Freezer now checks for nfreeze first
-Moved to version 0.18
-Added USR1 (non-verbose kernel state dumping) to Server
-Improved Server kernel state dumping
-
-Revision 1.11  2005/06/09 04:20:55  fil
-Reconciled
-Added check to put() to a closed wheel in Channel
-
-Revision 1.10  2004/05/13 19:51:21  fil
-Moved to signal_handled
-
-Revision 1.9  2002/05/02 19:35:54  fil
-Updated Chanages.
-Merged alias listing for publish/subtract
-Moved version
-
-Revision 1.8  2002/05/02 19:00:32  fil
-Fixed inform_monitor comming from IKC::Proxy/_stop.  We can't post()
-from _stop, so method call is turned into ->call().
-
-Revision 1.7  2001/09/06 23:13:42  fil
-Added doco for Responder->spawn
-Responder->spawn always returns true so that JAAS's factory doesn't complain
-
-Revision 1.6  2001/07/24 20:45:54  fil
-Fixed some win32 things like WSAEAFNOSUPPORT
-Added more tests to t/20_clientlite.t
-
-Revision 1.5  2001/07/13 06:59:45  fil
-Froze to 0.13
-
-Revision 1.4  2001/07/12 03:42:18  fil
-Added IKC::Channel::spawn
-Fixed IKC::Channel so that you can specify what module to use for
-    serialization.
-Added IKC::Freezer
-
-Revision 1.3  2001/07/06 02:27:51  fil
-Version 0.13pre9
-
-Revision 1.2  2001/07/06 02:23:35  fil
-Fixed bunch of things in doco
-Changed my e-mail address
